"use strict";
const axios_1 = require("axios");
const mqtt_topping_1 = require("mqtt-topping");
const Logger = require("bunyan");
async function getBootstrapData(logger) {
    const bootstrapUrl = process.env.BOOTSTRAP_SERVER_URI;
    logger.info({ bootstrapUrl }, "Retrieving bootstrap data from server");
    const bootstrapData = await queryBootstrapData(bootstrapUrl);
    logger.info(bootstrapData, "Bootstrap data retrieved from server");
    return bootstrapData;
}
async function queryBootstrapData(url) {
    try {
        const response = await axios_1.default.get(url, { timeout: 2000 });
        return response.data;
    }
    catch (e) {
        await delay(1000);
        return await queryBootstrapData(url);
    }
}
function delay(time) {
    return new Promise(resolve => {
        setTimeout(resolve, time);
    });
}
function createClientId(serviceId, device) {
    const uuid = Math.random().toString(16).substr(2, 8);
    if (device) {
        return `${serviceId}-${device}-${uuid}`;
    }
    else {
        return `${serviceId}-${uuid}`;
    }
}
module.exports = async function init(serviceId) {
    const logger = Logger.createLogger({
        name: serviceId,
        level: "debug",
        serializers: { error: Logger.stdSerializers.err }
    });
    const bootstrapData = await getBootstrapData(logger);
    const { device, tcpBrokerUri, httpBrokerUri, configServerUri } = bootstrapData;
    const clientId = createClientId(serviceId, device);
    logger.info({ tcpBrokerUri, httpBrokerUri, clientId }, "Connecting to Broker");
    const mqttClient = mqtt_topping_1.default.connect(tcpBrokerUri, httpBrokerUri, { clientId });
    mqttClient.on("connect", () => { logger.info("Connected to Broker"); });
    mqttClient.on("close", () => { logger.error("Disconnected from Broker"); });
    mqttClient.on("error", () => { logger.error("Error Connecting to Broker"); });
    async function queryConfig(config) {
        return axios_1.default(`${configServerUri}/master/${config}`);
    }
    return { logger, mqttClient, queryConfig, bootstrapData };
};
//# sourceMappingURL=main.js.map